# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlIoTSensorParameter(KeuzelijstField):
    """IoT-sensor parameters."""
    naam = 'KlIoTSensorParameter'
    label = 'IoT-sensor parameter'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlIoTSensorParameter'
    definition = 'IoT-sensor parameters.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlIoTSensorParameter'
    options = {
        'hoekverdraaiing': KeuzelijstWaarde(invulwaarde='hoekverdraaiing',
                                            label='Hoekverdraaiing',
                                            status='ingebruik',
                                            definitie='Hoekverdraaiing',
                                            objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlIoTSensorParameter/hoekverdraaiing'),
        'rek': KeuzelijstWaarde(invulwaarde='rek',
                                label='Rek',
                                status='ingebruik',
                                definitie='Rek',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlIoTSensorParameter/rek'),
        'temperatuur': KeuzelijstWaarde(invulwaarde='temperatuur',
                                        label='Temperatuur',
                                        status='ingebruik',
                                        definitie='Temperatuur',
                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlIoTSensorParameter/temperatuur'),
        'trillingen': KeuzelijstWaarde(invulwaarde='trillingen',
                                       label='Trillingen',
                                       status='ingebruik',
                                       definitie='Trillingen',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlIoTSensorParameter/trillingen'),
        'verplaatsing': KeuzelijstWaarde(invulwaarde='verplaatsing',
                                         label='Verplaatsing',
                                         status='ingebruik',
                                         definitie='Verplaatsing',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlIoTSensorParameter/verplaatsing'),
        'vibraties': KeuzelijstWaarde(invulwaarde='vibraties',
                                      label='Vibraties',
                                      status='verwijderd',
                                      definitie='Vibraties',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlIoTSensorParameter/vibraties'),
        'vibraties-of-trillingen': KeuzelijstWaarde(invulwaarde='vibraties-of-trillingen',
                                                    label='Vibraties of trillingen',
                                                    status='verwijderd',
                                                    definitie='Vibraties of trillingen',
                                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlIoTSensorParameter/vibraties-of-trillingen')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from ...Classes.Abstracten.Verlichtingstoestel import Verlichtingstoestel
from ...Classes.Abstracten.VerlichtingstoestelConnector import VerlichtingstoestelConnector
from otlmow_model.OtlmowModel.BaseClasses.BooleanField import BooleanField
from ...Datatypes.DteKleurRAL import DteKleurRAL, DteKleurRALWaarden
from ...Datatypes.KlArmatuurkleur import KlArmatuurkleur


# Generated with OTLClassCreator. To modify: extend, do not edit
class VerlichtingstoestelNaHP(Verlichtingstoestel, VerlichtingstoestelConnector):
    """Het geheel van de natrium hoge druk lamp (NaHP) en de behuizing die werden samengesteld met als doel: * de lichtstroom van de lichtbronnen hoofdzakelijk op het te verlichten oppervlak (doorlopende wegsectie, conflictgebied,...) te richten, teneinde de zichtbaarheid te verhogen; * de lichtstroom te beheersen zodat de weggebruikers niet verblind worden en de lichthinder beperkt wordt; * het optisch systeem, de lichtbronnen en de hulpapparatuur tegen uitwendige invloeden te beschermen"""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#VerlichtingstoestelNaHP'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#EMDraagconstructie', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Voorschakelapparaat', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Sturing', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Voorschakelapparaat', direction='u')  # u = unidirectional

        self._armatuurkleur = OTLAttribuut(field=DteKleurRAL,
                                           naam='armatuurkleur',
                                           label='armatuurkleur',
                                           objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#VerlichtingstoestelNaHP.armatuurkleur',
                                           usagenote='Attribuut uit gebruik sinds versie 2.3.0',
                                           deprecated_version='2.3.0',
                                           definition='De kleur van de zichtbare buitenkant van het verlichtingstoestel.',
                                           owner=self)

        self._heeftAntiVandalisme = OTLAttribuut(field=BooleanField,
                                                 naam='heeftAntiVandalisme',
                                                 label='heeft anti-vandalisme',
                                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#VerlichtingstoestelNaHP.heeftAntiVandalisme',
                                                 definition='Is het een antivandalisme type verlichtingstoestel?',
                                                 owner=self)

        self._heeftSperfilter = OTLAttribuut(field=BooleanField,
                                             naam='heeftSperfilter',
                                             label='heeft sperfilter',
                                             objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#VerlichtingstoestelNaHP.heeftSperfilter',
                                             definition='Is er een sperfilter aanwezig?',
                                             owner=self)

        self._kleurArmatuur = OTLAttribuut(field=KlArmatuurkleur,
                                           naam='kleurArmatuur',
                                           label='kleur armatuur',
                                           objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#VerlichtingstoestelNaHP.kleurArmatuur',
                                           definition='De kleur van de zichtbare buitenkant van het verlichtingstoestel.',
                                           owner=self)

    @property
    def armatuurkleur(self) -> DteKleurRALWaarden:
        """De kleur van de zichtbare buitenkant van het verlichtingstoestel."""
        return self._armatuurkleur.get_waarde()

    @armatuurkleur.setter
    def armatuurkleur(self, value):
        self._armatuurkleur.set_waarde(value, owner=self)

    @property
    def heeftAntiVandalisme(self) -> bool:
        """Is het een antivandalisme type verlichtingstoestel?"""
        return self._heeftAntiVandalisme.get_waarde()

    @heeftAntiVandalisme.setter
    def heeftAntiVandalisme(self, value):
        self._heeftAntiVandalisme.set_waarde(value, owner=self)

    @property
    def heeftSperfilter(self) -> bool:
        """Is er een sperfilter aanwezig?"""
        return self._heeftSperfilter.get_waarde()

    @heeftSperfilter.setter
    def heeftSperfilter(self, value):
        self._heeftSperfilter.set_waarde(value, owner=self)

    @property
    def kleurArmatuur(self) -> str:
        """De kleur van de zichtbare buitenkant van het verlichtingstoestel."""
        return self._kleurArmatuur.get_waarde()

    @kleurArmatuur.setter
    def kleurArmatuur(self, value):
        self._kleurArmatuur.set_waarde(value, owner=self)



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from ...Classes.Abstracten.MotorVermogenskring import MotorVermogenskring
from ...Classes.ImplementatieElement.AIMNaamObject import AIMNaamObject
from ...Datatypes.KlRelaisMerk import KlRelaisMerk
from ...Datatypes.KlRelaisModelnaam import KlRelaisModelnaam


# Generated with OTLClassCreator. To modify: extend, do not edit
class Relais(MotorVermogenskring, AIMNaamObject):
    """Een door een elektromagneet bediende schakelaar voor het schakelen van kleine vermogens. Ook magneetschakelaar genoemd."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Relais'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Sturing', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Niveaumeting', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Sturing', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#IOKaart', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#VoedtAangestuurd', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#MotorVermogenskring', direction='i')  # i = direction: incoming

        self._merk = OTLAttribuut(field=KlRelaisMerk,
                                  naam='merk',
                                  label='merk',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Relais.merk',
                                  definition='Merk van de relais volgens de fabrikant.',
                                  owner=self)

        self._modelnaam = OTLAttribuut(field=KlRelaisModelnaam,
                                       naam='modelnaam',
                                       label='modelnaam',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Relais.modelnaam',
                                       definition='Naam die de fabrikant zelf geeft aan het model of de uitvoering van de relais.',
                                       owner=self)

    @property
    def merk(self) -> str:
        """Merk van de relais volgens de fabrikant."""
        return self._merk.get_waarde()

    @merk.setter
    def merk(self, value):
        self._merk.set_waarde(value, owner=self)

    @property
    def modelnaam(self) -> str:
        """Naam die de fabrikant zelf geeft aan het model of de uitvoering van de relais."""
        return self._modelnaam.get_waarde()

    @modelnaam.setter
    def modelnaam(self, value):
        self._modelnaam.set_waarde(value, owner=self)



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from ...Classes.ImplementatieElement.NaampadObject import NaampadObject
from ...Datatypes.KlBinnenverlichtingGroepVerlichtGebied import KlBinnenverlichtingGroepVerlichtGebied
from otlmow_model.OtlmowModel.GeometrieTypes.PuntGeometrie import PuntGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class BinnenverlichtingGroep(NaampadObject, PuntGeometrie):
    """Een groep voor het groeperen van objecten van het type Binnenverlichtingstoestel."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/installatie#BinnenverlichtingGroep'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/implementatieelement#ActivityComplex', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/implementatieelement#ElectricityCable', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Beschermbuis', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Binnenverlichtingstoestel', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#VerlichtingstoestelTL', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Voedingskabel', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Wegkantkast', direction='i')  # i = direction: incoming

        self._verlichtGebied = OTLAttribuut(field=KlBinnenverlichtingGroepVerlichtGebied,
                                            naam='verlichtGebied',
                                            label='verlicht gebied',
                                            objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#BinnenverlichtingGroep.verlichtGebied',
                                            definition='Het gebied dat verlicht wordt door de binnenverlichtingstoestellen die deel uitmaken van de groep.',
                                            owner=self)

    @property
    def verlichtGebied(self) -> str:
        """Het gebied dat verlicht wordt door de binnenverlichtingstoestellen die deel uitmaken van de groep."""
        return self._verlichtGebied.get_waarde()

    @verlichtGebied.setter
    def verlichtGebied(self, value):
        self._verlichtGebied.set_waarde(value, owner=self)



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from ...Classes.Abstracten.SerienummerObject import SerienummerObject
from ...Classes.ImplementatieElement.AIMNaamObject import AIMNaamObject
from ...Datatypes.KlControlepaneelMerk import KlControlepaneelMerk
from ...Datatypes.KlControlepaneelModelnaam import KlControlepaneelModelnaam
from otlmow_model.OtlmowModel.GeometrieTypes.PuntGeometrie import PuntGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class Controlepaneel(SerienummerObject, AIMNaamObject, PuntGeometrie):
    """Een inrichting voor het besturen van een systeem dat of installatie die zich in de buurt van het controlepaneel bevindt. Een controlepaneel kan onder andere uitgerust zijn met schakelaars, drukknoppen, draaiknoppen, cijfertoetsen, signaallampen, etc."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Controlepaneel'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Kast', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Sturing', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#IOKaart', direction='u')  # u = unidirectional

        self._merk = OTLAttribuut(field=KlControlepaneelMerk,
                                  naam='merk',
                                  label='merk',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Controlepaneel.merk',
                                  definition='Het merk van het controlepaneel.',
                                  owner=self)

        self._modelnaam = OTLAttribuut(field=KlControlepaneelModelnaam,
                                       naam='modelnaam',
                                       label='modelnaam',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Controlepaneel.modelnaam',
                                       definition='De modelnaam van het controlepaneel',
                                       owner=self)

    @property
    def merk(self) -> str:
        """Het merk van het controlepaneel."""
        return self._merk.get_waarde()

    @merk.setter
    def merk(self, value):
        self._merk.set_waarde(value, owner=self)

    @property
    def modelnaam(self) -> str:
        """De modelnaam van het controlepaneel"""
        return self._modelnaam.get_waarde()

    @modelnaam.setter
    def modelnaam(self, value):
        self._modelnaam.set_waarde(value, owner=self)



# coding=utf-8
from ...Classes.Abstracten.Geleidingsmechanisme import Geleidingsmechanisme
from ...Classes.ImplementatieElement.AIMObject import AIMObject


# Generated with OTLClassCreator. To modify: extend, do not edit
class Centreermechanisme(Geleidingsmechanisme, AIMObject):
    """Een geleidingsmechanisme dat een beweegbaar constructieonderdeel begeleidt opdat het zich correct positioneert bij het beëindigen van de beweging."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Centreermechanisme'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Centreervork', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Draagstoel', direction='i')  # i = direction: incoming



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstField import KeuzelijstField


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlOverigeFunctiesOplegging(KeuzelijstField):
    """De overige functies van de oplegging."""
    naam = 'KlOverigeFunctiesOplegging'
    label = 'overige functies oplegging'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlOverigeFunctiesOplegging'
    definition = 'De overige functies van de oplegging.'
    status = 'https://wegenenverkeer-test.data.vlaanderen.be/id/concept/KlAdmsStatus/ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlOverigeFunctiesOplegging'
    options = {
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from ...Classes.ImplementatieElement.AIMObject import AIMObject
from ...Datatypes.DtcAfmetingBxlxhInCm import DtcAfmetingBxlxhInCm, DtcAfmetingBxlxhInCmWaarden
from otlmow_model.OtlmowModel.GeometrieTypes.PuntGeometrie import PuntGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class VerankeringsplaatMicropaal(AIMObject, PuntGeometrie):
    """Een stalen plaat gemonteerd op de micropaal, die aangespannen wordt en dient ter verankering van de micropaal."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#VerankeringsplaatMicropaal'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Micropaal', direction='u')  # u = unidirectional

        self._afmetingen = OTLAttribuut(field=DtcAfmetingBxlxhInCm,
                                        naam='afmetingen',
                                        label='afmetingen',
                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#VerankeringsplaatMicropaal.afmetingen',
                                        definition='Afmetingen van de verankeringsplaat voor de breedte, lengte en hoogte, in centimeter.',
                                        owner=self)

    @property
    def afmetingen(self) -> DtcAfmetingBxlxhInCmWaarden:
        """Afmetingen van de verankeringsplaat voor de breedte, lengte en hoogte, in centimeter."""
        return self._afmetingen.get_waarde()

    @afmetingen.setter
    def afmetingen(self, value):
        self._afmetingen.set_waarde(value, owner=self)



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from ...Classes.ImplementatieElement.AIMNaamObject import AIMNaamObject
from otlmow_model.OtlmowModel.BaseClasses.BooleanField import BooleanField
from ...Datatypes.DtcDocument import DtcDocument, DtcDocumentWaarden
from ...Datatypes.DteIPv4Adres import DteIPv4Adres, DteIPv4AdresWaarden
from ...Datatypes.KlANPRMerk import KlANPRMerk
from ...Datatypes.KlANPRModelnaam import KlANPRModelnaam
from ...Datatypes.KlAlgRijrichting import KlAlgRijrichting
from ...Datatypes.KwantWrdInMeter import KwantWrdInMeter, KwantWrdInMeterWaarden
from otlmow_model.OtlmowModel.BaseClasses.StringField import StringField
from otlmow_model.OtlmowModel.GeometrieTypes.PuntGeometrie import PuntGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class ANPRCamera(AIMNaamObject, PuntGeometrie):
    """Nummerplaatherkenningscamera: een camera die als output de nummerplaat van een voertuig in tekst geeft en een foto van het deel van het voertuig waar de nummerplaat zich bevindt. Afhankelijk van het merk en type gecombineerd met een al dan niet bewegend overzichtsbeeld."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#ANPRCamera'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    deprecated_version = '2.9.0'

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Draagconstructie', direction='u', deprecated='2.9.0')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestigingsbeugel', direction='u', deprecated='2.9.0')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#FieldOfView', direction='u', deprecated='2.4.0')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#ZuilTGC', direction='u', deprecated='2.9.0')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Trajectcontrole', direction='o', deprecated='2.9.0')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Sturing', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#SoftwareToegang', direction='u', deprecated='2.9.0')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Sturing', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Netwerkpoort', direction='u', deprecated='2.9.0')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Voedt', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#IpPowerSwitch', direction='i', deprecated='2.9.0')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Voedt', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Netwerkpoort', direction='i', deprecated='2.9.0')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Voedt', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Stroomkring', direction='i', deprecated='2.9.0')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Voedt', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#UPS', direction='i', deprecated='2.9.0')  # i = direction: incoming

        self._dnsNaam = OTLAttribuut(field=StringField,
                                     naam='dnsNaam',
                                     label='DNS naam',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#ANPRCamera.dnsNaam',
                                     usagenote='Klasse uit gebruik sinds versie 2.9.0',
                                     deprecated_version='2.9.0',
                                     definition='De DNSNaam (ook "volledige domein naam" genoemd ) is een unieke naam binnen het Domain Name System (DNS), het naamgevingssysteem waarmee computers, webservers, diensten en toepassing op een unieke manier kunnen worden geïdentificeerd. Deze bevat zowel de hostname en de top level domein naam bv. 120c8-ar1.belfa.be.',
                                     owner=self)

        self._heeftFlits = OTLAttribuut(field=BooleanField,
                                        naam='heeftFlits',
                                        label='heeft flits',
                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#ANPRCamera.heeftFlits',
                                        usagenote='Klasse uit gebruik sinds versie 2.9.0',
                                        deprecated_version='2.9.0',
                                        definition='Geeft aan of de camera een externe infrarood flits heeft.',
                                        owner=self)

        self._ipAdres = OTLAttribuut(field=DteIPv4Adres,
                                     naam='ipAdres',
                                     label='ip adres',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#ANPRCamera.ipAdres',
                                     usagenote='Klasse uit gebruik sinds versie 2.9.0',
                                     deprecated_version='2.9.0',
                                     definition='IP-adres van de ANPR-camera.',
                                     owner=self)

        self._merk = OTLAttribuut(field=KlANPRMerk,
                                  naam='merk',
                                  label='merk',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#ANPRCamera.merk',
                                  usagenote='Klasse uit gebruik sinds versie 2.9.0',
                                  deprecated_version='2.9.0',
                                  definition='Het merk van de ANPR-camera.',
                                  owner=self)

        self._modelnaam = OTLAttribuut(field=KlANPRModelnaam,
                                       naam='modelnaam',
                                       label='modelnaam',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#ANPRCamera.modelnaam',
                                       usagenote='Klasse uit gebruik sinds versie 2.9.0',
                                       deprecated_version='2.9.0',
                                       definition='De modelnaam van de ANPR-camera.',
                                       owner=self)

        self._opstelhoogte = OTLAttribuut(field=KwantWrdInMeter,
                                          naam='opstelhoogte',
                                          label='opstelhoogte',
                                          objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#ANPRCamera.opstelhoogte',
                                          usagenote='Klasse uit gebruik sinds versie 2.9.0 .NOTE',
                                          deprecated_version='2.9.0',
                                          definition='De hoogte waarop de camera bevestigd is, gemeten ten opzichte van het maaiveld waarin de draagconstructie voor de camera verankerd is.',
                                          owner=self)

        self._rijrichting = OTLAttribuut(field=KlAlgRijrichting,
                                         naam='rijrichting',
                                         label='rijrichting',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#ANPRCamera.rijrichting',
                                         usagenote='Klasse uit gebruik sinds versie 2.9.0',
                                         deprecated_version='2.9.0',
                                         definition='De rijrichting van de voertuigen die door de camera geregistreerd worden.',
                                         owner=self)

        self._technischeFiche = OTLAttribuut(field=DtcDocument,
                                             naam='technischeFiche',
                                             label='technische fiche',
                                             objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#ANPRCamera.technischeFiche',
                                             usagenote='Klasse uit gebruik sinds versie 2.9.0 .Bestanden van het type pdf.',
                                             deprecated_version='2.9.0',
                                             definition='Technische fiche van dit element.',
                                             owner=self)

    @property
    def dnsNaam(self) -> str:
        """De DNSNaam (ook "volledige domein naam" genoemd ) is een unieke naam binnen het Domain Name System (DNS), het naamgevingssysteem waarmee computers, webservers, diensten en toepassing op een unieke manier kunnen worden geïdentificeerd. Deze bevat zowel de hostname en de top level domein naam bv. 120c8-ar1.belfa.be."""
        return self._dnsNaam.get_waarde()

    @dnsNaam.setter
    def dnsNaam(self, value):
        self._dnsNaam.set_waarde(value, owner=self)

    @property
    def heeftFlits(self) -> bool:
        """Geeft aan of de camera een externe infrarood flits heeft."""
        return self._heeftFlits.get_waarde()

    @heeftFlits.setter
    def heeftFlits(self, value):
        self._heeftFlits.set_waarde(value, owner=self)

    @property
    def ipAdres(self) -> DteIPv4AdresWaarden:
        """IP-adres van de ANPR-camera."""
        return self._ipAdres.get_waarde()

    @ipAdres.setter
    def ipAdres(self, value):
        self._ipAdres.set_waarde(value, owner=self)

    @property
    def merk(self) -> str:
        """Het merk van de ANPR-camera."""
        return self._merk.get_waarde()

    @merk.setter
    def merk(self, value):
        self._merk.set_waarde(value, owner=self)

    @property
    def modelnaam(self) -> str:
        """De modelnaam van de ANPR-camera."""
        return self._modelnaam.get_waarde()

    @modelnaam.setter
    def modelnaam(self, value):
        self._modelnaam.set_waarde(value, owner=self)

    @property
    def opstelhoogte(self) -> KwantWrdInMeterWaarden:
        """De hoogte waarop de camera bevestigd is, gemeten ten opzichte van het maaiveld waarin de draagconstructie voor de camera verankerd is."""
        return self._opstelhoogte.get_waarde()

    @opstelhoogte.setter
    def opstelhoogte(self, value):
        self._opstelhoogte.set_waarde(value, owner=self)

    @property
    def rijrichting(self) -> str:
        """De rijrichting van de voertuigen die door de camera geregistreerd worden."""
        return self._rijrichting.get_waarde()

    @rijrichting.setter
    def rijrichting(self, value):
        self._rijrichting.set_waarde(value, owner=self)

    @property
    def technischeFiche(self) -> DtcDocumentWaarden:
        """Technische fiche van dit element."""
        return self._technischeFiche.get_waarde()

    @technischeFiche.setter
    def technischeFiche(self, value):
        self._technischeFiche.set_waarde(value, owner=self)



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from ...Classes.Abstracten.Lager import Lager
from ...Datatypes.KlWentellagerMerk import KlWentellagerMerk
from ...Datatypes.KlWentellagerModelnaam import KlWentellagerModelnaam
from ...Datatypes.KlWentellagerType import KlWentellagerType


# Generated with OTLClassCreator. To modify: extend, do not edit
class Wentellager(Lager):
    """Een wentellager of rollend lager is een lager waarin de wrijving wordt verminderd door het gebruiken van rollende elementen tussen de as en de boring. Afhankelijk van de aard en de vorm van het rollend element, spreken we van cilinderlagers, diabololagers, kegellagers, kogellagers, naaldlagers, bollagers of tonlagers."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Wentellager'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self._merk = OTLAttribuut(field=KlWentellagerMerk,
                                  naam='merk',
                                  label='merk',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Wentellager.merk',
                                  definition='Het merk van het lager.',
                                  owner=self)

        self._modelnaam = OTLAttribuut(field=KlWentellagerModelnaam,
                                       naam='modelnaam',
                                       label='modelnaam',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Wentellager.modelnaam',
                                       definition='De modelnaam volgens de fabrikant van het lager.',
                                       owner=self)

        self._type = OTLAttribuut(field=KlWentellagerType,
                                  naam='type',
                                  label='type',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Wentellager.type',
                                  definition='Geeft aan welk type wentellager hier gebruikt wordt.',
                                  owner=self)

    @property
    def merk(self) -> str:
        """Het merk van het lager."""
        return self._merk.get_waarde()

    @merk.setter
    def merk(self, value):
        self._merk.set_waarde(value, owner=self)

    @property
    def modelnaam(self) -> str:
        """De modelnaam volgens de fabrikant van het lager."""
        return self._modelnaam.get_waarde()

    @modelnaam.setter
    def modelnaam(self, value):
        self._modelnaam.set_waarde(value, owner=self)

    @property
    def type(self) -> str:
        """Geeft aan welk type wentellager hier gebruikt wordt."""
        return self._type.get_waarde()

    @type.setter
    def type(self, value):
        self._type.set_waarde(value, owner=self)



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlNetwerkconfiguratieWV(KeuzelijstField):
    """De mogelijke opties van de netwerkconfiguratie in het kader van de gesplitste netwerkenopstelling van de lichtpuntcontrole inzake wegverlichting."""
    naam = 'KlNetwerkconfiguratieWV'
    label = 'Netwerkconfiguratie wegverlichting'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlNetwerkconfiguratieWV'
    definition = 'De mogelijke opties van de netwerkconfiguratie in het kader van de gesplitste netwerkenopstelling van de lichtpuntcontrole inzake wegverlichting.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlNetwerkconfiguratieWV'
    options = {
        'black': KeuzelijstWaarde(invulwaarde='black',
                                  label='Black',
                                  status='ingebruik',
                                  definitie='Black',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkconfiguratieWV/black'),
        'blue': KeuzelijstWaarde(invulwaarde='blue',
                                 label='Blue',
                                 status='ingebruik',
                                 definitie='Blue',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkconfiguratieWV/blue'),
        'cyan': KeuzelijstWaarde(invulwaarde='cyan',
                                 label='Cyan',
                                 status='ingebruik',
                                 definitie='Cyan',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkconfiguratieWV/cyan'),
        'green': KeuzelijstWaarde(invulwaarde='green',
                                  label='Green',
                                  status='ingebruik',
                                  definitie='Green',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkconfiguratieWV/green'),
        'kleurloos': KeuzelijstWaarde(invulwaarde='kleurloos',
                                      label='Kleurloos',
                                      status='ingebruik',
                                      definitie='Kleurloos',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkconfiguratieWV/kleurloos'),
        'magenta': KeuzelijstWaarde(invulwaarde='magenta',
                                    label='Magenta',
                                    status='ingebruik',
                                    definitie='Magenta',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkconfiguratieWV/magenta'),
        'red': KeuzelijstWaarde(invulwaarde='red',
                                label='Red',
                                status='ingebruik',
                                definitie='Red',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkconfiguratieWV/red'),
        'yellow': KeuzelijstWaarde(invulwaarde='yellow',
                                   label='Yellow',
                                   status='ingebruik',
                                   definitie='Yellow',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkconfiguratieWV/yellow')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlBadgelezerProtocol(KeuzelijstField):
    """Lijst van protocollen gebruikt door badgelezers."""
    naam = 'KlBadgelezerProtocol'
    label = 'Badgelezer protocollen'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlBadgelezerProtocol'
    definition = 'Lijst van protocollen gebruikt door badgelezers.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlBadgelezerProtocol'
    options = {
        'rs485': KeuzelijstWaarde(invulwaarde='rs485',
                                  label='RS485',
                                  status='ingebruik',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBadgelezerProtocol/rs485')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlTypeMicropaal(KeuzelijstField):
    """De soort van de micropaal."""
    naam = 'KlTypeMicropaal'
    label = 'Type micropaal'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlTypeMicropaal'
    definition = 'De soort van de micropaal.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlTypeMicropaal'
    options = {
        'andere': KeuzelijstWaarde(invulwaarde='andere',
                                   label='Andere',
                                   status='ingebruik',
                                   definitie='Een ander type van micropaal. Details zijn terug te vinden in de technische fiche.',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlTypeMicropaal/andere'),
        'pds': KeuzelijstWaarde(invulwaarde='pds',
                                label='PDS',
                                status='ingebruik',
                                definitie='Micropaal vervaardigd door Penen Drilling System (PDS).',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlTypeMicropaal/pds'),
        'titan': KeuzelijstWaarde(invulwaarde='titan',
                                  label='Titan',
                                  status='ingebruik',
                                  definitie='Micropaal vervaardigd door Ischebeck TITAN.',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlTypeMicropaal/titan')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlAfdichtingsvoorzieningtype(KeuzelijstField):
    """De mogelijke types van een afdichtingsvoorziening."""
    naam = 'KlAfdichtingsvoorzieningtype'
    label = 'Afdichtingsvoorzieningtype'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlAfdichtingsvoorzieningtype'
    definition = 'De mogelijke types van een afdichtingsvoorziening.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlAfdichtingsvoorzieningtype'
    options = {
        'andere': KeuzelijstWaarde(invulwaarde='andere',
                                   label='andere',
                                   status='ingebruik',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAfdichtingsvoorzieningtype/andere'),
        'd-fender': KeuzelijstWaarde(invulwaarde='d-fender',
                                     label='d-fender',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAfdichtingsvoorzieningtype/d-fender'),
        'gina-profiel': KeuzelijstWaarde(invulwaarde='gina-profiel',
                                         label='gina-profiel',
                                         status='ingebruik',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAfdichtingsvoorzieningtype/gina-profiel'),
        'hoekprofiel': KeuzelijstWaarde(invulwaarde='hoekprofiel',
                                        label='hoekprofiel',
                                        status='ingebruik',
                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAfdichtingsvoorzieningtype/hoekprofiel'),
        'muzieknoot-met-dubbelzijdige-bevestiging': KeuzelijstWaarde(invulwaarde='muzieknoot-met-dubbelzijdige-bevestiging',
                                                                     label='muzieknoot met dubbelzijdige bevestiging',
                                                                     status='ingebruik',
                                                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAfdichtingsvoorzieningtype/muzieknoot-met-dubbelzijdige-bevestiging'),
        'muzieknoot-met-enkelzijdigde-bevestiging': KeuzelijstWaarde(invulwaarde='muzieknoot-met-enkelzijdigde-bevestiging',
                                                                     label='muzieknoot met enkelzijdigde bevestiging',
                                                                     status='ingebruik',
                                                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAfdichtingsvoorzieningtype/muzieknoot-met-enkelzijdigde-bevestiging'),
        'omega': KeuzelijstWaarde(invulwaarde='omega',
                                  label='omega',
                                  status='ingebruik',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAfdichtingsvoorzieningtype/omega'),
        'rubberflap': KeuzelijstWaarde(invulwaarde='rubberflap',
                                       label='rubberflap',
                                       status='ingebruik',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAfdichtingsvoorzieningtype/rubberflap')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlNeerslagsensorModelnaam(KeuzelijstField):
    """De modelnaam van de neerslagsensor."""
    naam = 'KlNeerslagsensorModelnaam'
    label = 'Neerslagsensor modelnaam'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlNeerslagsensorModelnaam'
    definition = 'De modelnaam van de neerslagsensor.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlNeerslagsensorModelnaam'
    options = {
        'WS100': KeuzelijstWaarde(invulwaarde='WS100',
                                  label='WS100',
                                  status='ingebruik',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNeerslagsensorModelnaam/WS100'),
        'drd11a': KeuzelijstWaarde(invulwaarde='drd11a',
                                   label='DRD11A',
                                   status='ingebruik',
                                   definitie='DRD11A',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNeerslagsensorModelnaam/drd11a')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from ...Classes.ImplementatieElement.AIMNaamObject import AIMNaamObject
from ...Datatypes.KlMateriaalVoegplaat import KlMateriaalVoegplaat
from otlmow_model.OtlmowModel.GeometrieTypes.PuntGeometrie import PuntGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class Voegplaat(AIMNaamObject, PuntGeometrie):
    """Een plaatvormig element dat in voegen van betonconstructies wordt aangebracht. Wordt veelal voorzien t.p.v. (gronddichte) uitzettingsvoegen."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Voegplaat'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#BalkGK', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Lmuur', direction='u')  # u = unidirectional

        self._materiaalVoegplaat = OTLAttribuut(field=KlMateriaalVoegplaat,
                                                naam='materiaalVoegplaat',
                                                label='materiaal voegplaat',
                                                objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Voegplaat.materiaalVoegplaat',
                                                definition='De verschillende opties van materiaal voor voegplaten.',
                                                owner=self)

    @property
    def materiaalVoegplaat(self) -> str:
        """De verschillende opties van materiaal voor voegplaten."""
        return self._materiaalVoegplaat.get_waarde()

    @materiaalVoegplaat.setter
    def materiaalVoegplaat(self, value):
        self._materiaalVoegplaat.set_waarde(value, owner=self)



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlTaludWaarde(KeuzelijstField):
    """De verschillende mogelijke waardes voor de hellingsgraad van de talud."""
    naam = 'KlTaludWaarde'
    label = 'Talud waarde'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlTaludWaarde'
    definition = 'De verschillende mogelijke waardes voor de hellingsgraad van de talud.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlTaludWaarde'
    options = {
        'tot-1-3': KeuzelijstWaarde(invulwaarde='tot-1-3',
                                    label='tot 1 3',
                                    status='ingebruik',
                                    definitie='Een hellingsgraad tot 1/3 (33,33%, 18,4°). ',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlTaludWaarde/tot-1-3'),
        'van-1-1-en-steiler': KeuzelijstWaarde(invulwaarde='van-1-1-en-steiler',
                                               label='van 1 1 en steiler',
                                               status='ingebruik',
                                               definitie='Hellingsgraad van 1/1 (100%, 45°) of steiler. ',
                                               objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlTaludWaarde/van-1-1-en-steiler'),
        'van-1-2-tot-1-1': KeuzelijstWaarde(invulwaarde='van-1-2-tot-1-1',
                                            label='van 1 2 tot 1 1',
                                            status='ingebruik',
                                            definitie='Een hellingsgraad van 1/2 (50%, 26,6%) tot 1/1 (100%, 45°). ',
                                            objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlTaludWaarde/van-1-2-tot-1-1'),
        'van-1-3-tot-1-2': KeuzelijstWaarde(invulwaarde='van-1-3-tot-1-2',
                                            label='van 1 3 tot 1 2',
                                            status='ingebruik',
                                            definitie='Een hellingsgraad van 1/3 (33,33%, 18,4°) tot 1/2 (50%, 26,6°). ',
                                            objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlTaludWaarde/van-1-3-tot-1-2')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
from ...Classes.Onderdeel.SoortenrijkSchraalGraslandGraslandfase5 import SoortenrijkSchraalGraslandGraslandfase5


# Generated with OTLClassCreator. To modify: extend, do not edit
class Kalkgrasland(SoortenrijkSchraalGraslandGraslandfase5):
    """G5c - blauwgras, bergdravik, duifkruid, grote centaurie, ruige scheefkelk, geel zonneroosje, kleine pimpernel, kalkwalstro, gevinde kortsteel, aarddistel, smal fakkelgras, driedistel."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Kalkgrasland'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlVWCTypeNivelleringssysteem(KeuzelijstField):
    """De mogelijke typen van het nivelleringssysteem van een vaste waterbouwkundige constructie."""
    naam = 'KlVWCTypeNivelleringssysteem'
    label = 'Type nivelleringssysteem'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/installatie#KlVWCTypeNivelleringssysteem'
    definition = 'De mogelijke typen van het nivelleringssysteem van een vaste waterbouwkundige constructie.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlVWCTypeNivelleringssysteem'
    options = {
        'door-de-deur': KeuzelijstWaarde(invulwaarde='door-de-deur',
                                         label='door de deur',
                                         status='ingebruik',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVWCTypeNivelleringssysteem/door-de-deur'),
        'niet-van-toepassing': KeuzelijstWaarde(invulwaarde='niet-van-toepassing',
                                                label='niet van toepassing',
                                                status='ingebruik',
                                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVWCTypeNivelleringssysteem/niet-van-toepassing'),
        'omloopriolen': KeuzelijstWaarde(invulwaarde='omloopriolen',
                                         label='omloopriolen',
                                         status='ingebruik',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVWCTypeNivelleringssysteem/omloopriolen'),
        'onder-de-deur': KeuzelijstWaarde(invulwaarde='onder-de-deur',
                                          label='onder de deur',
                                          status='ingebruik',
                                          objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVWCTypeNivelleringssysteem/onder-de-deur')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlDrukknopSoort(KeuzelijstField):
    """Keuzelijst met verschillende soorten drukknoppen."""
    naam = 'KlDrukknopSoort'
    label = 'Drukknop soort'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlDrukknopSoort'
    definition = 'Keuzelijst met verschillende soorten drukknoppen.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlDrukknopSoort'
    options = {
        'WV-drukknop': KeuzelijstWaarde(invulwaarde='WV-drukknop',
                                        label='WV drukknop',
                                        status='ingebruik',
                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlDrukknopSoort/WV-drukknop'),
        'combi-v-f-drukknop': KeuzelijstWaarde(invulwaarde='combi-v-f-drukknop',
                                               label='combi v f drukknop',
                                               status='ingebruik',
                                               objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlDrukknopSoort/combi-v-f-drukknop'),
        'combi-v-vg-drukknop': KeuzelijstWaarde(invulwaarde='combi-v-vg-drukknop',
                                                label='combi v vg drukknop',
                                                status='ingebruik',
                                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlDrukknopSoort/combi-v-vg-drukknop'),
        'fietser-drukknop': KeuzelijstWaarde(invulwaarde='fietser-drukknop',
                                             label='fietser drukknop',
                                             status='ingebruik',
                                             objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlDrukknopSoort/fietser-drukknop'),
        'ruiter-drukknop': KeuzelijstWaarde(invulwaarde='ruiter-drukknop',
                                            label='ruiter drukknop',
                                            status='ingebruik',
                                            objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlDrukknopSoort/ruiter-drukknop'),
        'visueel-gehandicapt-drukknop': KeuzelijstWaarde(invulwaarde='visueel-gehandicapt-drukknop',
                                                         label='visueel gehandicapt drukknop',
                                                         status='ingebruik',
                                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlDrukknopSoort/visueel-gehandicapt-drukknop'),
        'voetganger-drukknop': KeuzelijstWaarde(invulwaarde='voetganger-drukknop',
                                                label='voetganger drukknop',
                                                status='ingebruik',
                                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlDrukknopSoort/voetganger-drukknop')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from abc import abstractmethod, ABC
from ...Datatypes.DtcDocument import DtcDocument, DtcDocumentWaarden


# Generated with OTLClassCreator. To modify: extend, do not edit
class DetaiplanObject(ABC):
    """Abstracte dat het attribuut detailplan bevat."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#DetaiplanObject'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    @abstractmethod
    def __init__(self):
        super().__init__()

        self._detailplan = OTLAttribuut(field=DtcDocument,
                                        naam='detailplan',
                                        label='detailplan',
                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#DetaiplanObject.detailplan',
                                        definition='Dit plan bevat o.a. informatie over de materiaalkwaliteit, conservering en het verankeringssysteem.',
                                        owner=self)

    @property
    def detailplan(self) -> DtcDocumentWaarden:
        """Dit plan bevat o.a. informatie over de materiaalkwaliteit, conservering en het verankeringssysteem."""
        return self._detailplan.get_waarde()

    @detailplan.setter
    def detailplan(self, value):
        self._detailplan.set_waarde(value, owner=self)



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlLEACVoertuigOverhelling(KeuzelijstField):
    """De verschillende maten van voertuigoverhelling."""
    naam = 'KlLEACVoertuigOverhelling'
    label = 'Voertuig overhelling'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlLEACVoertuigOverhelling'
    definition = 'De verschillende maten van voertuigoverhelling.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlLEACVoertuigOverhelling'
    options = {
        'vIn1': KeuzelijstWaarde(invulwaarde='vIn1',
                                 label='vIn1',
                                 status='ingebruik',
                                 definitie='VIn <= 0.6',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLEACVoertuigOverhelling/vIn1'),
        'vIn2': KeuzelijstWaarde(invulwaarde='vIn2',
                                 label='vIn2',
                                 status='ingebruik',
                                 definitie='VIn <= 0.8',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLEACVoertuigOverhelling/vIn2'),
        'vIn3': KeuzelijstWaarde(invulwaarde='vIn3',
                                 label='vIn3',
                                 status='ingebruik',
                                 definitie='VIn <= 1.0',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLEACVoertuigOverhelling/vIn3'),
        'vIn4': KeuzelijstWaarde(invulwaarde='vIn4',
                                 label='vIn4',
                                 status='ingebruik',
                                 definitie='VIn <= 1.3',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLEACVoertuigOverhelling/vIn4'),
        'vIn5': KeuzelijstWaarde(invulwaarde='vIn5',
                                 label='vIn5',
                                 status='ingebruik',
                                 definitie='VIn <= 1.7',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLEACVoertuigOverhelling/vIn5'),
        'vIn6': KeuzelijstWaarde(invulwaarde='vIn6',
                                 label='vIn6',
                                 status='ingebruik',
                                 definitie='VIn <= 2.1',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLEACVoertuigOverhelling/vIn6'),
        'vIn7': KeuzelijstWaarde(invulwaarde='vIn7',
                                 label='vIn7',
                                 status='ingebruik',
                                 definitie='VIn <= 2.5',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLEACVoertuigOverhelling/vIn7'),
        'vIn8': KeuzelijstWaarde(invulwaarde='vIn8',
                                 label='vIn8',
                                 status='ingebruik',
                                 definitie='VIn <= 3.5',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLEACVoertuigOverhelling/vIn8'),
        'vIn9': KeuzelijstWaarde(invulwaarde='vIn9',
                                 label='vIn9',
                                 status='ingebruik',
                                 definitie='VIn > 3.5',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLEACVoertuigOverhelling/vIn9')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
from ...Classes.Onderdeel.Grasland import Grasland


# Generated with OTLClassCreator. To modify: extend, do not edit
class RaaigrasweideGraslandfase0(Grasland):
    """G0 - Zeer uniform grasland met vrijwel uitsluitend sterk glanzend gras Engels of Italiaans raaigras en/of ruw beemdgras dominant + vogelmuur, straatgras."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#RaaigrasweideGraslandfase0'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()



# coding=utf-8
from ...Classes.ImplementatieElement.AIMObject import AIMObject
from otlmow_model.OtlmowModel.GeometrieTypes.PuntGeometrie import PuntGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class Tandheugelmechanisme(AIMObject, PuntGeometrie):
    """Een mechanisme bestaande uit een tandheugel en een tandwiel dat wordt gebruikt om een lineaire beweging om te zetten in een roterende beweging of omgekeerd."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Tandheugelmechanisme'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Rol', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Tandheugel', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Tandwiel', direction='i')  # i = direction: incoming



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from ...Classes.Abstracten.Bestrating import Bestrating
from ...Datatypes.DtcBSSRandafwerking import DtcBSSRandafwerking, DtcBSSRandafwerkingWaarden
from ...Datatypes.KlBSSType import KlBSSType
from ...Datatypes.KlBestratingAfwerking import KlBestratingAfwerking
from ...Datatypes.KlBestratingselementAfmetingLxB import KlBestratingselementAfmetingLxB


# Generated with OTLClassCreator. To modify: extend, do not edit
class BestratingVanBetonstraatsteen(Bestrating):
    """Bestrating van geprefabriceerde stenen in beton die (in de afgesproken mate) voldoen aan de vereisten van NBN EN 1338 en NBN B21-311."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#BestratingVanBetonstraatsteen'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Fundering', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Markering', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#SelNietSelLus', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Straatmeubilair', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#IsInspectieVan', target='https://wegenenverkeer.data.vlaanderen.be/ns/proefenmeting#ProefLangsvlakheid', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#LigtOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#BegroeidVoorkomen', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#LigtOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Hoppinzuil', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#LigtOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Laag', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#LigtOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#LijnvormigElement', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#LigtOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#VegetatieElement', direction='i')  # i = direction: incoming

        self._afmetingVanBestratingselementLxB = OTLAttribuut(field=KlBestratingselementAfmetingLxB,
                                                              naam='afmetingVanBestratingselementLxB',
                                                              label='afmeting van bestratingselement LxB',
                                                              objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#BestratingVanBetonstraatsteen.afmetingVanBestratingselementLxB',
                                                              definition='De lengte en breedte van het bestratingselement in millimeter.',
                                                              owner=self)

        self._afwerking = OTLAttribuut(field=KlBestratingAfwerking,
                                       naam='afwerking',
                                       label='afwerking',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#BestratingVanBetonstraatsteen.afwerking',
                                       definition='Bepaling van afwerking van de betonstraatstenen.',
                                       owner=self)

        self._randafwerking = OTLAttribuut(field=DtcBSSRandafwerking,
                                           naam='randafwerking',
                                           label='randafwerking',
                                           objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#BestratingVanBetonstraatsteen.randafwerking',
                                           definition='De wijze waarop de rand van de betonstraatsteenverharding is afgewerkt.',
                                           owner=self)

        self._type = OTLAttribuut(field=KlBSSType,
                                  naam='type',
                                  label='type',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#BestratingVanBetonstraatsteen.type',
                                  definition='Het type betonstraatsteen.',
                                  owner=self)

    @property
    def afmetingVanBestratingselementLxB(self) -> str:
        """De lengte en breedte van het bestratingselement in millimeter."""
        return self._afmetingVanBestratingselementLxB.get_waarde()

    @afmetingVanBestratingselementLxB.setter
    def afmetingVanBestratingselementLxB(self, value):
        self._afmetingVanBestratingselementLxB.set_waarde(value, owner=self)

    @property
    def afwerking(self) -> str:
        """Bepaling van afwerking van de betonstraatstenen."""
        return self._afwerking.get_waarde()

    @afwerking.setter
    def afwerking(self, value):
        self._afwerking.set_waarde(value, owner=self)

    @property
    def randafwerking(self) -> DtcBSSRandafwerkingWaarden:
        """De wijze waarop de rand van de betonstraatsteenverharding is afgewerkt."""
        return self._randafwerking.get_waarde()

    @randafwerking.setter
    def randafwerking(self, value):
        self._randafwerking.set_waarde(value, owner=self)

    @property
    def type(self) -> str:
        """Het type betonstraatsteen."""
        return self._type.get_waarde()

    @type.setter
    def type(self, value):
        self._type.set_waarde(value, owner=self)



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from ...Classes.ImplementatieElement.AIMNaamObject import AIMNaamObject
from ...Datatypes.DtcAardingsstelsel import DtcAardingsstelsel, DtcAardingsstelselWaarden
from ...Datatypes.KlAardingAardingsnet import KlAardingAardingsnet
from ...Datatypes.KlAardingsInstallatieType import KlAardingsInstallatieType
from ...Datatypes.KwantWrdInOhm import KwantWrdInOhm, KwantWrdInOhmWaarden
from otlmow_model.OtlmowModel.GeometrieTypes.VlakGeometrie import VlakGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class Aardingsinstallatie(AIMNaamObject, VlakGeometrie):
    """Een galvanische verbinding van een elektrische installatie met de aarde. De elektrische installatie die op deze wijze met de aarde wordt verbonden krijgt een spanning van nul volt."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Aardingsinstallatie'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Aardingsinstallatie', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Cabine', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Aardingskabel', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Aardingslus', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Aardingsonderbreker', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Aardingspen', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Aardingsplaat', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#EquipotentiaalVerbinding', direction='i')  # i = direction: incoming

        self._aardingsinstallatietype = OTLAttribuut(field=KlAardingsInstallatieType,
                                                     naam='aardingsinstallatietype',
                                                     label='type aardingsinstallatietype',
                                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Aardingsinstallatie.aardingsinstallatietype',
                                                     definition='Mogelijke types van aardingsinstallaties.',
                                                     owner=self)

        self._aardingsnet = OTLAttribuut(field=KlAardingAardingsnet,
                                         naam='aardingsnet',
                                         label='aardingsnet',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Aardingsinstallatie.aardingsnet',
                                         definition='De manier waarop respectievelijk de bron en de verbruiker met de aarde verbonden worden om op die manier foutstromen af te voeren.',
                                         owner=self)

        self._aardingsstelsel = OTLAttribuut(field=DtcAardingsstelsel,
                                             naam='aardingsstelsel',
                                             label='aardingsstelsel',
                                             objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Aardingsinstallatie.aardingsstelsel',
                                             definition='De wijze waarop verschillende aardingen (bv. laagspanningsaarding, nulpuntsaarding, hoogspanningsaarding) zich t.o.v. elkaar bevinden: ofwel bevinden alle aardingen zich uit elkaars invloedssfeer en hebben ze geen impact op elkaars potentiaal ofwel zijn alle aardverbindingen galvanisch met elkaar in contact. In het eerste geval spreekt men van gescheiden aardingsstelsel, in het tweede geval van een globale aarding.',
                                             owner=self)

        self._aardingsweerstand = OTLAttribuut(field=KwantWrdInOhm,
                                               naam='aardingsweerstand',
                                               label='aardingsweerstand',
                                               objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Aardingsinstallatie.aardingsweerstand',
                                               definition='De grootte van de weerstand tussen de aardelektrode en de omringende grond.',
                                               owner=self)

    @property
    def aardingsinstallatietype(self) -> str:
        """Mogelijke types van aardingsinstallaties."""
        return self._aardingsinstallatietype.get_waarde()

    @aardingsinstallatietype.setter
    def aardingsinstallatietype(self, value):
        self._aardingsinstallatietype.set_waarde(value, owner=self)

    @property
    def aardingsnet(self) -> str:
        """De manier waarop respectievelijk de bron en de verbruiker met de aarde verbonden worden om op die manier foutstromen af te voeren."""
        return self._aardingsnet.get_waarde()

    @aardingsnet.setter
    def aardingsnet(self, value):
        self._aardingsnet.set_waarde(value, owner=self)

    @property
    def aardingsstelsel(self) -> DtcAardingsstelselWaarden:
        """De wijze waarop verschillende aardingen (bv. laagspanningsaarding, nulpuntsaarding, hoogspanningsaarding) zich t.o.v. elkaar bevinden: ofwel bevinden alle aardingen zich uit elkaars invloedssfeer en hebben ze geen impact op elkaars potentiaal ofwel zijn alle aardverbindingen galvanisch met elkaar in contact. In het eerste geval spreekt men van gescheiden aardingsstelsel, in het tweede geval van een globale aarding."""
        return self._aardingsstelsel.get_waarde()

    @aardingsstelsel.setter
    def aardingsstelsel(self, value):
        self._aardingsstelsel.set_waarde(value, owner=self)

    @property
    def aardingsweerstand(self) -> KwantWrdInOhmWaarden:
        """De grootte van de weerstand tussen de aardelektrode en de omringende grond."""
        return self._aardingsweerstand.get_waarde()

    @aardingsweerstand.setter
    def aardingsweerstand(self, value):
        self._aardingsweerstand.set_waarde(value, owner=self)



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstField import KeuzelijstField


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlVRModuleMetFirmwareMerk(KeuzelijstField):
    """Lijst met merken van VR-modules met firmware."""
    naam = 'KlVRModuleMetFirmwareMerk'
    label = 'VR-module met firmware merk'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#KlVRModuleMetFirmwareMerk'
    definition = 'Lijst met merken van VR-modules met firmware.'
    status = 'ingebruik'
    deprecated_version = '2.12.0'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlVRModuleMetFirmwareMerk'
    options = {
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from ...Classes.Abstracten.Constructiehoofd import Constructiehoofd
from ...Classes.ImplementatieElement.AIMNaamObject import AIMNaamObject
from otlmow_model.OtlmowModel.BaseClasses.BooleanField import BooleanField
from ...Datatypes.KlProfielVastAanslag import KlProfielVastAanslag


# Generated with OTLClassCreator. To modify: extend, do not edit
class Stuwhoofd(Constructiehoofd, AIMNaamObject):
    """Constructiehoofd van een stuw waarin één of meerdere stuwelementen zitten."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Stuwhoofd'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#AanhorigheidSluisStuw', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#ConstructieElementSluisStuw', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Grondkeringen', direction='i')  # i = direction: incoming

        self._heeftAanslagprofiel = OTLAttribuut(field=BooleanField,
                                                 naam='heeftAanslagprofiel',
                                                 label='heeft aanslagprofiel',
                                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Stuwhoofd.heeftAanslagprofiel',
                                                 definition='Geeft aan of er een aanslagprofiel aanwezig is.',
                                                 owner=self)

        self._profielVastAanslag = OTLAttribuut(field=KlProfielVastAanslag,
                                                naam='profielVastAanslag',
                                                label='materiaal aanslagprofiel',
                                                objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Stuwhoofd.profielVastAanslag',
                                                definition='Het gebruikte materiaal van het aanslagprofiel.',
                                                owner=self)

    @property
    def heeftAanslagprofiel(self) -> bool:
        """Geeft aan of er een aanslagprofiel aanwezig is."""
        return self._heeftAanslagprofiel.get_waarde()

    @heeftAanslagprofiel.setter
    def heeftAanslagprofiel(self, value):
        self._heeftAanslagprofiel.set_waarde(value, owner=self)

    @property
    def profielVastAanslag(self) -> str:
        """Het gebruikte materiaal van het aanslagprofiel."""
        return self._profielVastAanslag.get_waarde()

    @profielVastAanslag.setter
    def profielVastAanslag(self, value):
        self._profielVastAanslag.set_waarde(value, owner=self)



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from abc import abstractmethod
from ...Classes.Abstracten.FirmwareObject import FirmwareObject
from ...Classes.Abstracten.VerkeersregelaarModule import VerkeersregelaarModule
from ...Datatypes.KlVRModuleMetFirmwareMerk import KlVRModuleMetFirmwareMerk
from ...Datatypes.KlVRModuleMetFirmwareModelnaam import KlVRModuleMetFirmwareModelnaam


# Generated with OTLClassCreator. To modify: extend, do not edit
class VRModuleMetFirmware(FirmwareObject, VerkeersregelaarModule):
    """Abstracte voor modules met firmware van een verkeersregelaar."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#VRModuleMetFirmware'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    @abstractmethod
    def __init__(self):
        super().__init__()

        self._merk = OTLAttribuut(field=KlVRModuleMetFirmwareMerk,
                                  naam='merk',
                                  label='merk',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#VRModuleMetFirmware.merk',
                                  usagenote='Attribuut uit gebruik sinds versie 2.12.0',
                                  deprecated_version='2.12.0',
                                  definition='Het merk van de VR module met Firmware.',
                                  owner=self)

        self._modelnaam = OTLAttribuut(field=KlVRModuleMetFirmwareModelnaam,
                                       naam='modelnaam',
                                       label='modelnaam',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#VRModuleMetFirmware.modelnaam',
                                       definition='De modelnaam/product range van de VR module met Firmware.',
                                       owner=self)

    @property
    def merk(self) -> str:
        """Het merk van de VR module met Firmware."""
        return self._merk.get_waarde()

    @merk.setter
    def merk(self, value):
        self._merk.set_waarde(value, owner=self)

    @property
    def modelnaam(self) -> str:
        """De modelnaam/product range van de VR module met Firmware."""
        return self._modelnaam.get_waarde()

    @modelnaam.setter
    def modelnaam(self, value):
        self._modelnaam.set_waarde(value, owner=self)



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlToegankelijkheid(KeuzelijstField):
    """De mogelijke opties die de toegankelijkheid van een object aanduiden."""
    naam = 'KlToegankelijkheid'
    label = 'Toegankelijkheid'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/implementatieelement#KlToegankelijkheid'
    definition = 'De mogelijke opties die de toegankelijkheid van een object aanduiden.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlToegankelijkheid'
    options = {
        'is-bereikbaar-voor-inspectie': KeuzelijstWaarde(invulwaarde='is-bereikbaar-voor-inspectie',
                                                         label='is bereikbaar voor inspectie',
                                                         status='ingebruik',
                                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlToegankelijkheid/is-bereikbaar-voor-inspectie'),
        'is-betreedbaar': KeuzelijstWaarde(invulwaarde='is-betreedbaar',
                                           label='is betreedbaar',
                                           status='ingebruik',
                                           objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlToegankelijkheid/is-betreedbaar'),
        'niet-toegankelijk': KeuzelijstWaarde(invulwaarde='niet-toegankelijk',
                                              label='niet toegankelijk',
                                              status='ingebruik',
                                              objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlToegankelijkheid/niet-toegankelijk')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
from typing import List
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from ...Classes.Abstracten.Kokerruimte import Kokerruimte
from ...Classes.Abstracten.PutRelatie import PutRelatie
from otlmow_model.OtlmowModel.BaseClasses.BooleanField import BooleanField
from ...Datatypes.DtcDocument import DtcDocument, DtcDocumentWaarden
from ...Datatypes.KlPompKamerFunctie import KlPompKamerFunctie
from ...Datatypes.KwantWrdInKubiekeMeter import KwantWrdInKubiekeMeter, KwantWrdInKubiekeMeterWaarden
from ...Datatypes.KwantWrdInMaand import KwantWrdInMaand, KwantWrdInMaandWaarden
from ...Datatypes.KwantWrdInMillimeter import KwantWrdInMillimeter, KwantWrdInMillimeterWaarden


# Generated with OTLClassCreator. To modify: extend, do not edit
class Pompkamer(Kokerruimte, PutRelatie):
    """Elk volume,inclusief de bouwkundige elementen die dit volume bepalen,dat deel uitmaakt van het waterbouwkundig systeem van het pompstation en als zodanig onder water kan staan."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Pompkamer'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Niveaumeting', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestigingsbeugel', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Dompelpomp', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Gassensor', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Onderstel', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Pompgeleiding', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Pomphuis', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#PutBovenbouw', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Schacht', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#AndereLaag', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Grondanker', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Pompstation', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Funderingspaal', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Buis', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#LinkendElement', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#WaterloopRelatie', direction='i')  # i = direction: incoming

        self._breedte = OTLAttribuut(field=KwantWrdInMillimeter,
                                     naam='breedte',
                                     label='breedte',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Pompkamer.breedte',
                                     definition='De breedte van de pompkamer in millimeter, zoals uitgedrukt op het grondplan (eerst vermelde afmeting).',
                                     owner=self)

        self._diepte = OTLAttribuut(field=KwantWrdInMillimeter,
                                    naam='diepte',
                                    label='diepte',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Pompkamer.diepte',
                                    definition='De diepte van de pompkamer in meter, zoals uitgedrukt op het grondplan.',
                                    owner=self)

        self._functie = OTLAttribuut(field=KlPompKamerFunctie,
                                     naam='functie',
                                     label='functie',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Pompkamer.functie',
                                     definition='De specifieke functie die een pompkamer kan vervullen.',
                                     owner=self)

        self._isExplosieveilig = OTLAttribuut(field=BooleanField,
                                              naam='isExplosieveilig',
                                              label='is explosief veilig',
                                              objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Pompkamer.isExplosieveilig',
                                              definition='Geeft aan of de natte pompkelder voldoet aan de ATEX richtlijn.',
                                              owner=self)

        self._isLuchtdichtAfgesloten = OTLAttribuut(field=BooleanField,
                                                    naam='isLuchtdichtAfgesloten',
                                                    label='is luchtdicht afgesloten',
                                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Pompkamer.isLuchtdichtAfgesloten',
                                                    definition='Geeft aan of de natte pompkelder hermetisch afgesloten is van de omgeving.',
                                                    owner=self)

        self._lengte = OTLAttribuut(field=KwantWrdInMillimeter,
                                    naam='lengte',
                                    label='lengte',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Pompkamer.lengte',
                                    definition='De lengte van de pompkamer in millimeter, zoals uitgedrukt op het grondplan (tweede vermelde afmeting) .',
                                    owner=self)

        self._reinigingsInterval = OTLAttribuut(field=KwantWrdInMaand,
                                                naam='reinigingsInterval',
                                                label='reinigingsinterval',
                                                objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Pompkamer.reinigingsInterval',
                                                definition='Termijn uitgedrukt in maanden waarbinnen de reiniging van de pompkamer uitgevoerd dient te worden.',
                                                owner=self)

        self._technischeFiche = OTLAttribuut(field=DtcDocument,
                                             naam='technischeFiche',
                                             label='technische fiche',
                                             objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Pompkamer.technischeFiche',
                                             usagenote='Bestanden van het type xlsx, dwg of pdf.',
                                             kardinaliteit_max='*',
                                             definition='De technische fiche van de pompkamer.',
                                             owner=self)

        self._volume = OTLAttribuut(field=KwantWrdInKubiekeMeter,
                                    naam='volume',
                                    label='volume',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Pompkamer.volume',
                                    definition='De (maximale) inhoud van de pompkamer.',
                                    owner=self)

    @property
    def breedte(self) -> KwantWrdInMillimeterWaarden:
        """De breedte van de pompkamer in millimeter, zoals uitgedrukt op het grondplan (eerst vermelde afmeting)."""
        return self._breedte.get_waarde()

    @breedte.setter
    def breedte(self, value):
        self._breedte.set_waarde(value, owner=self)

    @property
    def diepte(self) -> KwantWrdInMillimeterWaarden:
        """De diepte van de pompkamer in meter, zoals uitgedrukt op het grondplan."""
        return self._diepte.get_waarde()

    @diepte.setter
    def diepte(self, value):
        self._diepte.set_waarde(value, owner=self)

    @property
    def functie(self) -> str:
        """De specifieke functie die een pompkamer kan vervullen."""
        return self._functie.get_waarde()

    @functie.setter
    def functie(self, value):
        self._functie.set_waarde(value, owner=self)

    @property
    def isExplosieveilig(self) -> bool:
        """Geeft aan of de natte pompkelder voldoet aan de ATEX richtlijn."""
        return self._isExplosieveilig.get_waarde()

    @isExplosieveilig.setter
    def isExplosieveilig(self, value):
        self._isExplosieveilig.set_waarde(value, owner=self)

    @property
    def isLuchtdichtAfgesloten(self) -> bool:
        """Geeft aan of de natte pompkelder hermetisch afgesloten is van de omgeving."""
        return self._isLuchtdichtAfgesloten.get_waarde()

    @isLuchtdichtAfgesloten.setter
    def isLuchtdichtAfgesloten(self, value):
        self._isLuchtdichtAfgesloten.set_waarde(value, owner=self)

    @property
    def lengte(self) -> KwantWrdInMillimeterWaarden:
        """De lengte van de pompkamer in millimeter, zoals uitgedrukt op het grondplan (tweede vermelde afmeting) ."""
        return self._lengte.get_waarde()

    @lengte.setter
    def lengte(self, value):
        self._lengte.set_waarde(value, owner=self)

    @property
    def reinigingsInterval(self) -> KwantWrdInMaandWaarden:
        """Termijn uitgedrukt in maanden waarbinnen de reiniging van de pompkamer uitgevoerd dient te worden."""
        return self._reinigingsInterval.get_waarde()

    @reinigingsInterval.setter
    def reinigingsInterval(self, value):
        self._reinigingsInterval.set_waarde(value, owner=self)

    @property
    def technischeFiche(self) -> List[DtcDocumentWaarden]:
        """De technische fiche van de pompkamer."""
        return self._technischeFiche.get_waarde()

    @technischeFiche.setter
    def technischeFiche(self, value):
        self._technischeFiche.set_waarde(value, owner=self)

    @property
    def volume(self) -> KwantWrdInKubiekeMeterWaarden:
        """De (maximale) inhoud van de pompkamer."""
        return self._volume.get_waarde()

    @volume.setter
    def volume(self, value):
        self._volume.set_waarde(value, owner=self)



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlTypeDrempel(KeuzelijstField):
    """De keuzelijst die de verschillende type van drempels bevat."""
    naam = 'KlTypeDrempel'
    label = 'Keuzelijst type drempel'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlTypeDrempel'
    definition = 'De keuzelijst die de verschillende type van drempels bevat.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlTypeDrempel'
    options = {
        'gelijkliggende-drempel': KeuzelijstWaarde(invulwaarde='gelijkliggende-drempel',
                                                   label='gelijkliggende drempel',
                                                   status='ingebruik',
                                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlTypeDrempel/gelijkliggende-drempel'),
        'opstande': KeuzelijstWaarde(invulwaarde='opstande',
                                     label='opstande',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlTypeDrempel/opstande')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from ...Classes.Abstracten.TechnischDocument import TechnischDocument
from ...Classes.ImplementatieElement.AIMNaamObject import AIMNaamObject
from ...Datatypes.KlMateriaalBusEnRing import KlMateriaalBusEnRing
from otlmow_model.OtlmowModel.GeometrieTypes.PuntGeometrie import PuntGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class BusMechanisch(TechnischDocument, AIMNaamObject, PuntGeometrie):
    """Een cilindervormig onderdeel dat vaak als voering of geleider wordt gebruikt in mechanische verbindingen. Voorbeelden hiervan zijn afstandsbus en demontagebus. De hoogte is groter dan de wanddikte."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#BusMechanisch'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Rolgeleiding', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Scharnierpunt', direction='o')  # o = direction: outgoing

        self._materiaalBus = OTLAttribuut(field=KlMateriaalBusEnRing,
                                          naam='materiaalBus',
                                          label='materiaal bus',
                                          objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#BusMechanisch.materiaalBus',
                                          definition='Het materiaal waaruit de bus is vervaardigd.',
                                          owner=self)

    @property
    def materiaalBus(self) -> str:
        """Het materiaal waaruit de bus is vervaardigd."""
        return self._materiaalBus.get_waarde()

    @materiaalBus.setter
    def materiaalBus(self, value):
        self._materiaalBus.set_waarde(value, owner=self)



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from abc import abstractmethod
from ...Datatypes.KwantWrdInKilogram import KwantWrdInKilogram, KwantWrdInKilogramWaarden
from ...Datatypes.KwantWrdInMeter import KwantWrdInMeter, KwantWrdInMeterWaarden
from otlmow_model.OtlmowModel.GeometrieTypes.VlakGeometrie import VlakGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class ElementSpecificatie(VlakGeometrie):
    """De abstracte die de specificaties per element verzameld."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#ElementSpecificatie'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    @abstractmethod
    def __init__(self):
        super().__init__()

        self._elementBreedte = OTLAttribuut(field=KwantWrdInMeter,
                                            naam='elementBreedte',
                                            label='element breedte',
                                            objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#ElementSpecificatie.elementBreedte',
                                            definition='De breedte van één element.',
                                            owner=self)

        self._elementGewicht = OTLAttribuut(field=KwantWrdInKilogram,
                                            naam='elementGewicht',
                                            label='element gewicht',
                                            objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#ElementSpecificatie.elementGewicht',
                                            definition='Het gewicht van één element.',
                                            owner=self)

        self._elementLengte = OTLAttribuut(field=KwantWrdInMeter,
                                           naam='elementLengte',
                                           label='element lengte',
                                           objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#ElementSpecificatie.elementLengte',
                                           definition='De lengte van één element.',
                                           owner=self)

    @property
    def elementBreedte(self) -> KwantWrdInMeterWaarden:
        """De breedte van één element."""
        return self._elementBreedte.get_waarde()

    @elementBreedte.setter
    def elementBreedte(self, value):
        self._elementBreedte.set_waarde(value, owner=self)

    @property
    def elementGewicht(self) -> KwantWrdInKilogramWaarden:
        """Het gewicht van één element."""
        return self._elementGewicht.get_waarde()

    @elementGewicht.setter
    def elementGewicht(self, value):
        self._elementGewicht.set_waarde(value, owner=self)

    @property
    def elementLengte(self) -> KwantWrdInMeterWaarden:
        """De lengte van één element."""
        return self._elementLengte.get_waarde()

    @elementLengte.setter
    def elementLengte(self, value):
        self._elementLengte.set_waarde(value, owner=self)



# coding=utf-8
from ...Classes.Abstracten.PTModuleZFirmware import PTModuleZFirmware


# Generated with OTLClassCreator. To modify: extend, do not edit
class PTDemodulatoren(PTModuleZFirmware):
    """De functie van de demodulator bestaat erin de data,ontvangen door de lus,te decoderen en in het juiste formaat door te sturen naar de centrale verwerkingseenheid,de PT-verwerkingseenheid."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#PTDemodulatoren'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#PTVerwerkingseenheid', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Sturing', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SelectieveDetectielus', direction='u')  # u = unidirectional



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlTypeNutsvoorziening(KeuzelijstField):
    """Het type nutsvoorziening van een straatkap verwijst naar de specifieke aard van de nutsinfrastructuur waartoe het deksel toegang biedt."""
    naam = 'KlTypeNutsvoorziening'
    label = 'Keuzelijst type nutsvoorziening'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlTypeNutsvoorziening'
    definition = 'Het type nutsvoorziening van een straatkap verwijst naar de specifieke aard van de nutsinfrastructuur waartoe het deksel toegang biedt.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlTypeNutsvoorziening'
    options = {
        'brandkraan': KeuzelijstWaarde(invulwaarde='brandkraan',
                                       label='brandkraan',
                                       status='ingebruik',
                                       definitie='brandkraan',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlTypeNutsvoorziening/brandkraan'),
        'elektriciteit': KeuzelijstWaarde(invulwaarde='elektriciteit',
                                          label='elektriciteit',
                                          status='ingebruik',
                                          definitie='elektriciteit',
                                          objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlTypeNutsvoorziening/elektriciteit'),
        'gas': KeuzelijstWaarde(invulwaarde='gas',
                                label='gas',
                                status='ingebruik',
                                definitie='gas',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlTypeNutsvoorziening/gas'),
        'telecom': KeuzelijstWaarde(invulwaarde='telecom',
                                    label='telecom',
                                    status='ingebruik',
                                    definitie='telecom',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlTypeNutsvoorziening/telecom'),
        'water': KeuzelijstWaarde(invulwaarde='water',
                                  label='water',
                                  status='ingebruik',
                                  definitie='water',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlTypeNutsvoorziening/water')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from ...Classes.Abstracten.AanhorigheidSluisStuw import AanhorigheidSluisStuw
from ...Classes.ImplementatieElement.AIMNaamObject import AIMNaamObject
from ...Datatypes.DtcAfmetingBxhInM import DtcAfmetingBxhInM, DtcAfmetingBxhInMWaarden
from ...Datatypes.KlMateriaalStormraam import KlMateriaalStormraam
from ...Datatypes.KwantWrdInMeter import KwantWrdInMeter, KwantWrdInMeterWaarden
from otlmow_model.OtlmowModel.GeometrieTypes.LijnGeometrie import LijnGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class Stormraam(AanhorigheidSluisStuw, AIMNaamObject, LijnGeometrie):
    """Open raamwerk dat aan zeezijde van de afwaartse sluisdeur tegen de sluisdeur geplaatst wordt en vergrendeld door het inschuiven van een spie via verticale cilinder op de deur. Bij voorspelde storm vermijdt dit schade door het voorkomen van klapperen van de afwaartse deuren bij grote stormgolven en wisselende waterdruk."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Stormraam'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self._afmetingen = OTLAttribuut(field=DtcAfmetingBxhInM,
                                        naam='afmetingen',
                                        label='afmetingen',
                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Stormraam.afmetingen',
                                        definition='De afmetingen, hoogte en breedte, van een stormraam',
                                        owner=self)

        self._materiaalStormraam = OTLAttribuut(field=KlMateriaalStormraam,
                                                naam='materiaalStormraam',
                                                label='materiaal stormraam',
                                                objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Stormraam.materiaalStormraam',
                                                definition='Het gebruikte materiaal voor het stormraam.',
                                                owner=self)

        self._ontwerpwaardeVanNegatieveVerval = OTLAttribuut(field=KwantWrdInMeter,
                                                             naam='ontwerpwaardeVanNegatieveVerval',
                                                             label='ontwerpwaarde van negatieve verval',
                                                             objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Stormraam.ontwerpwaardeVanNegatieveVerval',
                                                             definition='De ontwerpwaarde van negatieve verval, uitgedrukt in meter.',
                                                             owner=self)

    @property
    def afmetingen(self) -> DtcAfmetingBxhInMWaarden:
        """De afmetingen, hoogte en breedte, van een stormraam"""
        return self._afmetingen.get_waarde()

    @afmetingen.setter
    def afmetingen(self, value):
        self._afmetingen.set_waarde(value, owner=self)

    @property
    def materiaalStormraam(self) -> str:
        """Het gebruikte materiaal voor het stormraam."""
        return self._materiaalStormraam.get_waarde()

    @materiaalStormraam.setter
    def materiaalStormraam(self, value):
        self._materiaalStormraam.set_waarde(value, owner=self)

    @property
    def ontwerpwaardeVanNegatieveVerval(self) -> KwantWrdInMeterWaarden:
        """De ontwerpwaarde van negatieve verval, uitgedrukt in meter."""
        return self._ontwerpwaardeVanNegatieveVerval.get_waarde()

    @ontwerpwaardeVanNegatieveVerval.setter
    def ontwerpwaardeVanNegatieveVerval(self, value):
        self._ontwerpwaardeVanNegatieveVerval.set_waarde(value, owner=self)



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from ...Classes.Abstracten.ComplexeGeleiding import ComplexeGeleiding
from ...Datatypes.KwantWrdInMeter import KwantWrdInMeter, KwantWrdInMeterWaarden
from otlmow_model.OtlmowModel.GeometrieTypes.VlakGeometrie import VlakGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class Veerooster(ComplexeGeleiding, VlakGeometrie):
    """Een veerooster is een infrastructurele voorziening die is aangebracht in het wegdek om te voorkomen dat vee een gebied binnenkomt of verlaat."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Veerooster'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#ComplexeGeleiding', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#ConstructieElement', direction='i')  # i = direction: incoming

        self._breedte = OTLAttribuut(field=KwantWrdInMeter,
                                     naam='breedte',
                                     label='breedte',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Veerooster.breedte',
                                     definition='De breedte van het veerooster in meter.',
                                     owner=self)

    @property
    def breedte(self) -> KwantWrdInMeterWaarden:
        """De breedte van het veerooster in meter."""
        return self._breedte.get_waarde()

    @breedte.setter
    def breedte(self, value):
        self._breedte.set_waarde(value, owner=self)



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlToegangsprocedureAandachtspunt(KeuzelijstField):
    """De soorten aandachtspunten voor toegang tot een object."""
    naam = 'KlToegangsprocedureAandachtspunt'
    label = 'Toegangsprocedure aandachtspunt'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/implementatieelement#KlToegangsprocedureAandachtspunt'
    definition = 'De soorten aandachtspunten voor toegang tot een object.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlToegangsprocedureAandachtspunt'
    options = {
        'botser-nodig': KeuzelijstWaarde(invulwaarde='botser-nodig',
                                         label='botser nodig',
                                         status='ingebruik',
                                         definitie='botser nodig',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlToegangsprocedureAandachtspunt/botser-nodig'),
        'hoogtewerker-nodig': KeuzelijstWaarde(invulwaarde='hoogtewerker-nodig',
                                               label='hoogtewerker nodig',
                                               status='ingebruik',
                                               definitie='hoogtewerker nodig',
                                               objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlToegangsprocedureAandachtspunt/hoogtewerker-nodig'),
        'niet-machinaal-bereikbaar': KeuzelijstWaarde(invulwaarde='niet-machinaal-bereikbaar',
                                                      label='niet machinaal bereikbaar',
                                                      status='ingebruik',
                                                      definitie='Het object kan niet bereikt worden met een machine voor bijvoorbeeld reiniging, onderhoud of vervanging.',
                                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlToegangsprocedureAandachtspunt/niet-machinaal-bereikbaar')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from abc import abstractmethod
from ...Classes.Abstracten.SerienummerObject import SerienummerObject
from ...Classes.ImplementatieElement.AIMNaamObject import AIMNaamObject
from ...Datatypes.KwantWrdInMeterTAW import KwantWrdInMeterTAW, KwantWrdInMeterTAWWaarden
from otlmow_model.OtlmowModel.GeometrieTypes.PuntGeometrie import PuntGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class Niveaumeting(SerienummerObject, AIMNaamObject, PuntGeometrie):
    """Abstracte om alle methodes van niveau- of peilmeting te groeperen."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Niveaumeting'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    @abstractmethod
    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Pompkamer', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Silo', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Tank', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Pompstation', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Sturing', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#IOKaart', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Sturing', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#PLC', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Sturing', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Relais', direction='u')  # u = unidirectional

        self._meetbereik = OTLAttribuut(field=KwantWrdInMeterTAW,
                                        naam='meetbereik',
                                        label='meetbereik',
                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Niveaumeting.meetbereik',
                                        definition='Het meetbereik van de niveaumeting, uitgedrukt in meter TAW.',
                                        owner=self)

    @property
    def meetbereik(self) -> KwantWrdInMeterTAWWaarden:
        """Het meetbereik van de niveaumeting, uitgedrukt in meter TAW."""
        return self._meetbereik.get_waarde()

    @meetbereik.setter
    def meetbereik(self, value):
        self._meetbereik.set_waarde(value, owner=self)



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from ...Classes.Abstracten.Verkeerslicht import Verkeerslicht
from ...Datatypes.KlVriBewaking import KlVriBewaking


# Generated with OTLClassCreator. To modify: extend, do not edit
class VerkeerslichtRood(Verkeerslicht):
    """Een lichtbron met rode kleur om de weggebruikers aan te geven dat het verboden is de stopstreep of, zo er geen stopstreep is, het verkeerslicht zelf, voorbij te rijden."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#VerkeerslichtRood'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Seinlantaarn', direction='u')  # u = unidirectional

        self._typeBewaking = OTLAttribuut(field=KlVriBewaking,
                                          naam='typeBewaking',
                                          label='type bewaking',
                                          objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#VerkeerslichtRood.typeBewaking',
                                          definition='Type bewaking van het rode verkeerslicht.',
                                          owner=self)

    @property
    def typeBewaking(self) -> str:
        """Type bewaking van het rode verkeerslicht."""
        return self._typeBewaking.get_waarde()

    @typeBewaking.setter
    def typeBewaking(self, value):
        self._typeBewaking.set_waarde(value, owner=self)



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstField import KeuzelijstField


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlBetonnenDamplankvorm(KeuzelijstField):
    """De vorm van de betonnen damplank."""
    naam = 'KlBetonnenDamplankvorm'
    label = 'Betonnen damplankvorm'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlBetonnenDamplankvorm'
    definition = 'De vorm van de betonnen damplank.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlBetonnenDamplankvorm'
    options = {
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from ...Classes.Abstracten.BetonnenConstructieElement import BetonnenConstructieElement
from ...Classes.ImplementatieElement.AIMNaamObject import AIMNaamObject
from otlmow_model.OtlmowModel.BaseClasses.BooleanField import BooleanField
from ...Datatypes.DtcAfmetingBxlxhInM import DtcAfmetingBxlxhInM, DtcAfmetingBxlxhInMWaarden
from otlmow_model.OtlmowModel.GeometrieTypes.VlakGeometrie import VlakGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class Sluisvloertegel(BetonnenConstructieElement, AIMNaamObject, VlakGeometrie):
    """Een betontegel met grote afmetingen specifiek van toepassing voor de bodem van een sluis."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Sluisvloertegel'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Kolkvloer', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#LigtOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Draineerlaag', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#LigtOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Geotextiel', direction='o')  # o = direction: outgoing

        self._afmetingen = OTLAttribuut(field=DtcAfmetingBxlxhInM,
                                        naam='afmetingen',
                                        label='afmetingen',
                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Sluisvloertegel.afmetingen',
                                        definition='De afmetingen van de sluisvloertegel: breedte, lengte en hoogte, uitgedrukt in meter.',
                                        owner=self)

        self._heeftVoegbanden = OTLAttribuut(field=BooleanField,
                                             naam='heeftVoegbanden',
                                             label='heeft voegbanden',
                                             objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Sluisvloertegel.heeftVoegbanden',
                                             definition='Geeft aan of de sluisvloertegel al dan niet voegbanden heeft',
                                             owner=self)

    @property
    def afmetingen(self) -> DtcAfmetingBxlxhInMWaarden:
        """De afmetingen van de sluisvloertegel: breedte, lengte en hoogte, uitgedrukt in meter."""
        return self._afmetingen.get_waarde()

    @afmetingen.setter
    def afmetingen(self, value):
        self._afmetingen.set_waarde(value, owner=self)

    @property
    def heeftVoegbanden(self) -> bool:
        """Geeft aan of de sluisvloertegel al dan niet voegbanden heeft"""
        return self._heeftVoegbanden.get_waarde()

    @heeftVoegbanden.setter
    def heeftVoegbanden(self, value):
        self._heeftVoegbanden.set_waarde(value, owner=self)



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from ...Classes.ImplementatieElement.AIMObject import AIMObject
from ...Datatypes.DtcDocument import DtcDocument, DtcDocumentWaarden
from ...Datatypes.KlBrandwerendeMaatregelen import KlBrandwerendeMaatregelen
from ...Datatypes.KlGebruikersType import KlGebruikersType
from ...Datatypes.KlKokerTypeFundering import KlKokerTypeFundering
from ...Datatypes.KwantWrdInCentimeter import KwantWrdInCentimeter, KwantWrdInCentimeterWaarden
from otlmow_model.OtlmowModel.GeometrieTypes.LijnGeometrie import LijnGeometrie
from otlmow_model.OtlmowModel.GeometrieTypes.VlakGeometrie import VlakGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class Koker(AIMObject, LijnGeometrie, VlakGeometrie):
    """Een koker is een opdeling van het kokercomplex in de lengte richting, het heeft een doorvoerende functie met een in- en uitgang en eventuele zijgangen, die met een gesloten doorsnede verbonden zijn. """

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Koker'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#AanhorigheidKoker', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#AndereLaag', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Grondanker', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Balk', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#HorizontaleConstructieplaat', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Kokercomplex', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Kolom', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Omroepzone', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Randprofiel', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Wand', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#ConstructieSokkel', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#DynBordPK', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Funderingspaal', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Kokervoeg', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#PutBovenbouw', direction='i')  # i = direction: incoming

        self._brandwerendeMaatregelen = OTLAttribuut(field=KlBrandwerendeMaatregelen,
                                                     naam='brandwerendeMaatregelen',
                                                     label='type brandwerendheid',
                                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Koker.brandwerendeMaatregelen',
                                                     definition='Keuzelijst voor aan te geven welk type brandwerendheid nodig is.',
                                                     owner=self)

        self._gebruikersInDeKoker = OTLAttribuut(field=KlGebruikersType,
                                                 naam='gebruikersInDeKoker',
                                                 label='gebruikers in de koker',
                                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Koker.gebruikersInDeKoker',
                                                 definition='Geeft de type gebruikers aan die kunnen voorkomen in de desbetreffende koker.',
                                                 owner=self)

        self._maximaleVrijeHoogte = OTLAttribuut(field=KwantWrdInCentimeter,
                                                 naam='maximaleVrijeHoogte',
                                                 label='maximale vrije hoogte',
                                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Koker.maximaleVrijeHoogte',
                                                 definition='Hoogte die door gebruikers kan gehanteerd worden voor vervoer, rekening houdend met voorwerpen die aan de koker bevestigd zijn.',
                                                 owner=self)

        self._ontwerpbelasting = OTLAttribuut(field=DtcDocument,
                                              naam='ontwerpbelasting',
                                              label='ontwerpbelasting',
                                              objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Koker.ontwerpbelasting',
                                              definition='De ontwerpbelasting is de maximale belasting die een constructie kan opnemen zonder te bezwijken.',
                                              owner=self)

        self._typeFundering = OTLAttribuut(field=KlKokerTypeFundering,
                                           naam='typeFundering',
                                           label='type fundering',
                                           objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Koker.typeFundering',
                                           definition='Het type fundering dat gebruikt wordt voor de koker.',
                                           owner=self)

    @property
    def brandwerendeMaatregelen(self) -> str:
        """Keuzelijst voor aan te geven welk type brandwerendheid nodig is."""
        return self._brandwerendeMaatregelen.get_waarde()

    @brandwerendeMaatregelen.setter
    def brandwerendeMaatregelen(self, value):
        self._brandwerendeMaatregelen.set_waarde(value, owner=self)

    @property
    def gebruikersInDeKoker(self) -> str:
        """Geeft de type gebruikers aan die kunnen voorkomen in de desbetreffende koker."""
        return self._gebruikersInDeKoker.get_waarde()

    @gebruikersInDeKoker.setter
    def gebruikersInDeKoker(self, value):
        self._gebruikersInDeKoker.set_waarde(value, owner=self)

    @property
    def maximaleVrijeHoogte(self) -> KwantWrdInCentimeterWaarden:
        """Hoogte die door gebruikers kan gehanteerd worden voor vervoer, rekening houdend met voorwerpen die aan de koker bevestigd zijn."""
        return self._maximaleVrijeHoogte.get_waarde()

    @maximaleVrijeHoogte.setter
    def maximaleVrijeHoogte(self, value):
        self._maximaleVrijeHoogte.set_waarde(value, owner=self)

    @property
    def ontwerpbelasting(self) -> DtcDocumentWaarden:
        """De ontwerpbelasting is de maximale belasting die een constructie kan opnemen zonder te bezwijken."""
        return self._ontwerpbelasting.get_waarde()

    @ontwerpbelasting.setter
    def ontwerpbelasting(self, value):
        self._ontwerpbelasting.set_waarde(value, owner=self)

    @property
    def typeFundering(self) -> str:
        """Het type fundering dat gebruikt wordt voor de koker."""
        return self._typeFundering.get_waarde()

    @typeFundering.setter
    def typeFundering(self, value):
        self._typeFundering.set_waarde(value, owner=self)



# coding=utf-8
from abc import abstractmethod, ABC


# Generated with OTLClassCreator. To modify: extend, do not edit
class AanhorigheidSluisStuw(ABC):
    """Een bundeling van aanhorigheden die bij een Sluis en/of Stuw kunnen horen."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#AanhorigheidSluisStuw'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    @abstractmethod
    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Constructiehoofd', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#BeweegbareWaterkerendeConstructie', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Fuik', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Kolk', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Sluishoofd', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Stuwhoofd', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#TijdelijkeWaterkerendeConstructie', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#VasteWaterbouwkundigeConstructie', direction='u')  # u = unidirectional

        pass
